@@ -18,11 +18,13 @@ import traceback
 import warnings
 try:                    # Python 3
     import configparser
+    from threading import current_thread
     from xmlrpc.client import Fault, ServerProxy
     basestring = str
     int_types = int
 except ImportError:     # Python 2
     import ConfigParser as configparser
+    from threading import currentThread as current_thread
     from xmlrpclib import Fault, ServerProxy
     int_types = int, long
 
@@ -38,18 +40,17 @@ except ImportError:
     def _convert(node):
         if isinstance(node, _ast.Str):
             return node.s
-        elif isinstance(node, _ast.Num):
+        if isinstance(node, _ast.Num):
             return node.n
-        elif isinstance(node, _ast.Tuple):
+        if isinstance(node, _ast.Tuple):
             return tuple(map(_convert, node.elts))
-        elif isinstance(node, _ast.List):
+        if isinstance(node, _ast.List):
             return list(map(_convert, node.elts))
-        elif isinstance(node, _ast.Dict):
-            return dict((_convert(k), _convert(v)) for k, v
-                        in zip(node.keys, node.values))
-        elif isinstance(node, _ast.Name):
-            if node.id in SAFE_CONSTANTS:
-                return SAFE_CONSTANTS[node.id]
+        if isinstance(node, _ast.Dict):
+            return dict((_convert(k), _convert(v))
+                        for (k, v) in zip(node.keys, node.values))
+        if isinstance(node, _ast.Name) and node.id in SAFE_CONSTANTS:
+            return SAFE_CONSTANTS[node.id]
         raise ValueError('malformed or disallowed expression')
 
     def literal_eval(node_or_string):
@@ -61,7 +62,7 @@ except ImportError:
         return _convert(node_or_string)
 
 
-__version__ = '1.4.2'
+__version__ = '1.4.3'
 __all__ = ['Client', 'Model', 'Record', 'RecordList', 'Service',
            'format_exception', 'read_config', 'start_openerp_services']
 
@@ -92,9 +93,6 @@ Usage (main commands):
     access(obj, mode='read')        # Check access on the model
 
     do(obj, method, *params)        # Generic 'object.execute'
-    wizard(name)                    # Return the 'id' of a new wizard
-    wizard(name_or_id, datas=None, action='init')
-                                    # Generic 'wizard.execute'
     exec_workflow(obj, signal, id)  # Trigger workflow signal
 
     client                          # Client object, connected
@@ -123,16 +121,16 @@ _methods = {
     'common': ['about', 'login', 'timezone_get', 'get_server_environment',
                'login_message', 'check_connectivity'],
     'object': ['execute', 'exec_workflow'],
-    'wizard': ['execute', 'create'],
     'report': ['report', 'report_get'],
+    'wizard': ['execute', 'create'],
 }
 _methods_6_1 = {
     'db': ['create_database', 'db_exist'],
     'common': ['get_stats', 'list_http_services', 'version',
                'authenticate', 'get_os_time', 'get_sqlcount'],
     'object': ['execute_kw'],
-    'wizard': [],
     'report': ['render_report'],
+    'wizard': [],
 }
 # Hidden methods:
 #  - (not in 6.1) 'common': ['logout', 'ir_get', 'ir_set', 'ir_del']
@@ -227,19 +225,21 @@ def start_openerp_services(options=None):
 
     Import the ``openerp`` package and load the OpenERP services.
     The argument `options` receives the command line arguments for ``openerp``.
-    Example: ``-c /path/to/openerp-server.conf --without-demo all``.
+    Example: ``"-c /path/to/openerp-server.conf --without-demo all"``.
     Return the openerp module.
     """
     import openerp
-    from threading import currentThread
     global get_pool
     if not openerp.osv.osv.service:
         os.environ['TZ'] = 'UTC'
         options = options and options.split() or []
         openerp.tools.config.parse_config(options)
-        openerp.netsvc.init_logger()
-        openerp.osv.osv.start_object_proxy()
-        openerp.service.web_services.start_web_services()
+        if openerp.release.version_info < (7,):
+            openerp.netsvc.init_logger()
+            openerp.osv.osv.start_object_proxy()
+            openerp.service.web_services.start_web_services()
+        else:
+            openerp.service.start_internal()
 
     # Helper; use get_pool(db_name).db.cursor() to grab a cursor
     def get_pool(db_name=None):
@@ -247,8 +247,6 @@ def start_openerp_services(options=None):
         if not db_name:
             db_name = client._db
         pool = openerp.modules.registry.RegistryManager.get(db_name)
-        # Used for logging, copied from openerp.sql_db.db_connect
-        currentThread().dbname = db_name
         return pool
     return openerp
 
@@ -405,8 +403,8 @@ class Client(object):
         self.db = get_proxy('db')
         self.common = get_proxy('common')
         self._object = get_proxy('object')
-        self._wizard = get_proxy('wizard')
         self._report = get_proxy('report')
+        self._wizard = get_proxy('wizard') if major_version < '7.0' else None
         if db:
             # Try to login
             self._login(user, password=password, database=db)
@@ -445,15 +443,17 @@ class Client(object):
         else:
             print('Error: Not connected')
             return
+        # Used for logging, copied from openerp.sql_db.db_connect
+        current_thread().dbname = database
         (uid, password) = self._auth(database, user, password)
         if not uid:
             if not self._db:
                 self._db = database
             print('Error: Invalid username or password')
             return
-        if database and self._db != database:
+        if self._db != database:
+            self._db = database
             self._environment = None
-        self._db = database
         self.user = user
 
         # Authenticated endpoints
@@ -461,14 +461,15 @@ class Client(object):
             return functools.partial(method, self._db, uid, password)
         self._execute = authenticated(self._object.execute)
         self._exec_workflow = authenticated(self._object.exec_workflow)
-        self._wizard_execute = authenticated(self._wizard.execute)
-        self._wizard_create = authenticated(self._wizard.create)
         self.report = authenticated(self._report.report)
         self.report_get = authenticated(self._report.report_get)
         if self.major_version != '5.0':
             # Only for OpenERP >= 6
             self.execute_kw = authenticated(self._object.execute_kw)
             self.render_report = authenticated(self._report.render_report)
+        if self._wizard:
+            self._wizard_execute = authenticated(self._wizard.execute)
+            self._wizard_create = authenticated(self._wizard.create)
         return uid
 
     # Needed for interactive use
@@ -664,6 +665,8 @@ class Client(object):
         If the `name` is a string, the wizard is created before the execution.
         The optional `datas` argument provides data for the action.
         The optional `context` argument is passed to the RPC method.
+
+        Removed in OpenERP 7.
         """
         if isinstance(name, int_types):
             wiz_id = name
@@ -883,7 +886,7 @@ class Client(object):
             rv = self.model(lowercase(method))
             self.__dict__[method] = rv
             return rv
-        if method.startswith('__'):
+        if method.startswith('_'):
             raise AttributeError("'Client' object has no attribute %r" %
                                  method)
 
@@ -1019,10 +1022,9 @@ class Model(object):
             elif field_type in ('one2many', 'many2many'):
                 rel_model = self.client.model(field['relation'])
                 values[key] = RecordList(rel_model, value, context=context)
-            elif field_type == 'reference':
-                if value:
-                    res_model, res_id = value.split(',')
-                    values[key] = Record(self.client.model(res_model), int(res_id))
+            elif value and field_type == 'reference':
+                res_model, res_id = value.split(',')
+                values[key] = Record(self.client.model(res_model), int(res_id))
         return values
 
     def _unbrowse_values(self, values):
@@ -1084,6 +1086,7 @@ class RecordList(object):
             '_model': res_model,
             '_idnames': ids,
             '_context': context,
+            '_execute': res_model._execute,
         })
 
     def __repr__(self):
@@ -1142,7 +1145,7 @@ class RecordList(object):
         if context is None and self._context:
             context = self._context
         values = self._model._unbrowse_values(values)
-        rv = self._model._execute('write', self.id, values, context=context)
+        rv = self._execute('write', self.id, values, context=context)
         return rv
 
     def unlink(self, context=None):
@@ -1151,7 +1154,7 @@ class RecordList(object):
             return True
         if context is None and self._context:
             context = self._context
-        rv = self._model._execute('unlink', self.id, context=context)
+        rv = self._execute('unlink', self.id, context=context)
         return rv
 
     def __getitem__(self, key):
@@ -1165,7 +1168,7 @@ class RecordList(object):
         context = self._context
         if attr in self._model._keys:
             return self.read(attr, context=context)
-        if attr.startswith('__'):
+        if attr.startswith('_'):
             errmsg = "'RecordList' object has no attribute %r" % attr
             raise AttributeError(errmsg)
         if attr == '_ids':
@@ -1173,16 +1176,14 @@ class RecordList(object):
             warnings.warn("Attribute 'RecordList._ids' is deprecated, "
                           "use 'RecordList.id' instead.")
             return self.id
-        model_name = self._model_name
-        execute = self._model._execute
 
         def wrapper(self, *params, **kwargs):
             """Wrapper for client.execute(%r, %r, [...], *params, **kwargs)."""
             if context:
                 kwargs.setdefault('context', context)
-            return execute(attr, self.id, *params, **kwargs)
+            return self._execute(attr, self.id, *params, **kwargs)
         wrapper.__name__ = attr
-        wrapper.__doc__ %= (model_name, attr)
+        wrapper.__doc__ %= (self._model_name, attr)
         self.__dict__[attr] = mobj = wrapper.__get__(self, type(self))
         return mobj
 
@@ -1217,6 +1218,7 @@ class Record(object):
             '_model': res_model,
             '_context': context,
             '_cached_keys': set(),
+            '_execute': res_model._execute,
         })
 
     def __repr__(self):
@@ -1227,7 +1229,7 @@ class Record(object):
 
     def _get_name(self):
         try:
-            (id_name,) = self._model._execute('name_get', [self.id])
+            (id_name,) = self._execute('name_get', [self.id])
             name = '[%d] %s' % (self.id, id_name[1])
         except Exception:
             name = '[%d] -' % (self.id,)
@@ -1275,7 +1277,7 @@ class Record(object):
         Return a dictionary of values.
         See :meth:`Client.perm_read` for details.
         """
-        rv = self._model._execute('perm_read', [self.id], context=context)
+        rv = self._execute('perm_read', [self.id], context=context)
         return rv and rv[0] or None
 
     def write(self, values, context=None):
@@ -1283,7 +1285,7 @@ class Record(object):
         if context is None and self._context:
             context = self._context
         values = self._model._unbrowse_values(values)
-        rv = self._model._execute('write', [self.id], values, context=context)
+        rv = self._execute('write', [self.id], values, context=context)
         self.refresh()
         return rv
 
@@ -1291,7 +1293,7 @@ class Record(object):
         """Delete the current :class:`Record` from the database."""
         if context is None and self._context:
             context = self._context
-        rv = self._model._execute('unlink', [self.id], context=context)
+        rv = self._execute('unlink', [self.id], context=context)
         self.refresh()
         return rv
 
@@ -1305,7 +1307,7 @@ class Record(object):
             context = self._context
         if default:
             default = self._model._unbrowse_values(default)
-        new_id = self._model._execute('copy', self.id, default, context=context)
+        new_id = self._execute('copy', self.id, default, context=context)
         return Record(self._model, new_id)
 
     def _send(self, signal):
@@ -1327,7 +1329,7 @@ class Record(object):
         if attr == '_name':
             self.__dict__['_name'] = name = self._get_name()
             return name
-        if attr.startswith('__'):
+        if attr.startswith('_'):
             raise AttributeError("'Record' object has no attribute %r" % attr)
         if attr == 'client':
             # deprecated since 1.2.1
@@ -1339,7 +1341,7 @@ class Record(object):
             """Wrapper for client.execute(%r, %r, %d, *params, **kwargs)."""
             if context:
                 kwargs.setdefault('context', context)
-            res = self._model._execute(attr, [self.id], *params, **kwargs)
+            res = self._execute(attr, [self.id], *params, **kwargs)
             if isinstance(res, list) and len(res) == 1:
                 return res[0]
             return res
